@@ -2,8 +2,9 @@ use crate::utilities;
 use crate::Trustee;
 use std::ffi::OsStr;
 
-/// Wraps BuildTrusteeWithNameW
+/// Wraps [`BuildTrusteeWithNameW`](https://docs.microsoft.com/en-us/windows/win32/api/aclapi/nf-aclapi-buildtrusteewithnamew)
 #[allow(non_snake_case)]
+#[allow(clippy::needless_lifetimes)]
 pub fn BuildTrusteeWithName<'s>(name_buf: &'s [u16]) -> Trustee<'s> {
     let mut trustee = unsafe { Trustee::allocate() };
 
@@ -17,7 +18,7 @@ pub fn BuildTrusteeWithName<'s>(name_buf: &'s [u16]) -> Trustee<'s> {
     trustee
 }
 
-/// Copies the `OsStr` into WTF-16 before creating the `Trustee`
+/// Copies the `OsStr` into WTF-16 before creating the `Trustee`.
 #[allow(non_snake_case)]
 pub fn BuildTrusteeWithNameOsStr(name: &OsStr) -> Trustee<'static> {
     // Convert name into a static WTF-16 buffer
