@@ -2,13 +2,24 @@ use crate::utilities::os_from_buf;
 use crate::Sid;
 use std::ffi::OsString;
 use std::io;
-use std::ptr::{null, null_mut};
+use std::ptr::null;
 
 const BUFFER_SIZE: u32 = 256;
 
-/// Wraps LookupAccountSidW
+/// Wraps [`LookupAccountSidW`](https://docs.microsoft.com/en-us/windows/win32/api/winbase/nf-winbase-lookupaccountsidw).
 ///
-/// Returns (name, domain)
+/// Returns (name, domain).
+///
+/// ```
+/// use windows_permissions::{Sid, LocalBox, wrappers::LookupAccountSid};
+/// use winapi::um::winnt::WinBuiltinAdministratorsSid;
+///
+/// let sid = Sid::well_known_sid(WinBuiltinAdministratorsSid).unwrap();
+/// let (name, domain) = LookupAccountSid(&sid).unwrap();
+///
+/// assert_eq!(name, "Administrators");
+/// assert_eq!(domain, "BUILTIN");
+/// ```
 #[allow(non_snake_case)]
 pub fn LookupAccountSid(sid: &Sid) -> Result<(OsString, OsString), io::Error> {
     let mut name_size = BUFFER_SIZE;
@@ -21,6 +32,8 @@ pub fn LookupAccountSid(sid: &Sid) -> Result<(OsString, OsString), io::Error> {
         let mut name: Vec<u16> = vec![0; name_size as usize];
         let mut dom: Vec<u16> = vec![0; dom_size as usize];
 
+        let mut name_use: u32 = 0;
+
         let result = unsafe {
             winapi::um::winbase::LookupAccountSidW(
                 null(),
@@ -29,7 +42,7 @@ pub fn LookupAccountSid(sid: &Sid) -> Result<(OsString, OsString), io::Error> {
                 &mut name_size,
                 dom.as_mut_ptr(),
                 &mut dom_size,
-                null_mut(),
+                &mut name_use,
             )
         };
 
